#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from taz.dls import Datalake
import sys
import tests.config as cfg


class DatalakeTests(unittest.TestCase):

    def setUp(self):

        self.path = cfg.dls["path"]
        self.glob_path = cfg.dls["glob_path"]
        self.file_name = cfg.dls["file_name"]
        self.gz_file_name = cfg.dls["gz_file_name"]
        self.tmp_file_name = cfg.dls["tmp_file_name"]
        self.datalake = Datalake(
            cfg.dls["dls_name"],
            cfg.dls["tenant_id"],
            cfg.dls["client_id"],
            cfg.dls["client_secret"],
            proxy=cfg.dls["https_proxy"])

    def test_020_glob(self):
        list_files = self.datalake.glob(self.glob_path)
        print(list_files)
        self.assertTrue(list_files)


if __name__ == '__main__':
    sys.argv.append('-v')
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from azure.common.client_factory import get_client_from_cli_profile
from azure.mgmt.msi import ManagedServiceIdentityClient
from azure.mgmt.containerinstance.models import ContainerGroupIdentity
from msrestazure.azure_active_directory import MSIAuthentication
from azure.common.credentials import ServicePrincipalCredentials


import os


class UserAssignedIdentity:

    """User Assigned identity
    
    Attributes:
        - client (ManagedServiceIdentityClient): MSI client
        - container_group_identity (ContainerGroupIdentity): identity to use
        with container group
        - identity (TYPE): Description
        - managed_identity_name (TYPE): Description
        - resource_group_name (string): Resource Group
        - subscription_id (string): subscription id
    """

    def __init__(
        self, resource_group_name, managed_identity_name, subscription_id=None
    ):
        """
        Create a user assigned identity object

        Args:
            resource_group (string): resource group name
            managed_identity (string): managed identity name
            subscription_id (None, optional): subscription id (if None default)
        """
        try:
            if subscription_id is None:
                self.client = get_client_from_cli_profile(ManagedServiceIdentityClient)
            else:
                self.client = get_client_from_cli_profile(
                    ManagedServiceIdentityClient, subscription_id=subscription_id
                )
        except:
            self.client = ManagedServiceIdentityClient(MSIAuthentication())

        self.subscription_id = subscription_id
        self.resource_group_name = resource_group_name
        self.managed_identity_name = managed_identity_name

    def get_identity(self):
        self.identity = self.client.user_assigned_identities.get(
            self.resource_group_name, self.managed_identity_name
        )

        return self.identity

    def get_container_group_identity(self):
        self.get_identity()

        self.container_group_identity = ContainerGroupIdentity(
            type="UserAssigned", user_assigned_identities={self.identity.id: {}}
        )
        return self.container_group_identity


class MsiAuthentication:
    def __init__(self):
        self.credentials = MSIAuthentication()

    def get_credentials(self):
        return self.credentials


class ClientSecretAuthentication:
    def __init__(
        self, tenant_id=None, subscription_id=None, client_id=None, client_secret=None
    ):
        """Client/Client secret authentication
        
        :param tenant_id: tenant_id or AZURE_TENANT_ID env var, defaults to None
        :type tenant_id: string, optional
        :param subscription_id: subscription_id or AZURE_SUBSCRIPTION_ID env var, defaults to None
        :type subscription_id: string, optional
        :param client_id: client_id or AZURE_CLIENT_ID env var, defaults to None
        :type client_id: string, optional
        :param client_secret: client_secret or AZURE_CLIENT_SECRET env var, defaults to None
        :type client_secret: string, optional
        """
        if tenant_id is None:
            self.tenant_id = os.environ.get("AZURE_TENANT_ID")
        else:
            self.tenant_id = tenant_id

        if subscription_id is None:
            self.subscription_id = os.environ.get("AZURE_SUBSCRIPTION_ID")
        else:
            self.subscription_id = subscription_id

        if client_id is None:
            self.client_id = os.environ.get("AZURE_CLIENT_ID")
        else:
            self.client_id = client_id

        if client_secret is None:
            self.client_secret = os.environ.get("AZURE_CLIENT_SECRET")
        else:
            self.client_secret = client_secret

        self.credentials = ServicePrincipalCredentials(
            tenant=self.tenant_id, client_id=self.client_id, secret=self.client_secret
        )

    def get_credentials(self):
        return self.credentials



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from azure.common.client_factory import get_client_from_cli_profile
from azure.mgmt.containerregistry import ContainerRegistryManagementClient
from taz.acr import ContainerRegistry
from msrestazure.azure_active_directory import MSIAuthentication
from azure.mgmt.containerinstance.container_instance_management_client import (
    ContainerInstanceManagementClient,
)

from azure.mgmt.containerinstance.models import (
    ContainerGroup,
    Container,
    ContainerGroupNetworkProtocol,
    ContainerPort,
    EnvironmentVariable,
    IpAddress,
    Port,
    ResourceRequests,
    ResourceRequirements,
    OperatingSystemTypes,
)

from taz.auth import UserAssignedIdentity, ClientSecretAuthentication
import json
import os
from azure.common.credentials import ServicePrincipalCredentials


class SimpleContainerGroup:

    """Summary
    
    Attributes:
        - client (ContainerInstanceManagementClient): ACI management client
        - command (string): container entry point
        - cpus (int): vcpus
        - env_vars (list): environment variables
        - group (ContainerGroup): container group
        - identity (TYPE): Description
        - image (TYPE): Description
        - instances (list): Description
        - location (TYPE): Description
        - mem (int): Description
        - name (TYPE): Description
        - os_type (TYPE): Description
        - resource_group_name (TYPE): Description
        - restart_policy (str): Description
        - mode (string): connection mode based on environment vars
        AZURE_TENANT_ID, AZURE_CLIENT_ID, AZURE_CLIENT_SECRET and AZURE_CLI_USER
            - "service_principal": service principal authentication if AZURE_CLIENT_SECRET is set
            - "cli_profile": CLI based authentication if AZURE_CLI_USER var is set
            - "msi": MSI otherwise
    """

    def __init__(
        self, name, resource_group_name, location, image, subscription_id=None
    ):
        """
        Simple container group object with one instance
        
        Args:
            - name (str): container group name
            - resource_group_name (str): resource group
            - location (str): location (westeurope for example)
            - image (taz.acr.ContainerImage): ContainerImage object
            - subscription_id (None, optional, str): subscription 
                id if not default, can also be set by env var
                AZURE_SUBSCRIPTION_ID (parameter first)
        """

        self.tenant_id = os.environ.get("AZURE_TENANT_ID")
        self.client_id = os.environ.get("AZURE_CLIENT_ID")
        self.cli_user = os.environ.get("AZURE_CLI_USER")
        if subscription_id:
            self.subscription_id = subscription_id
        else:
            self.subscription_id = os.environ.get("AZURE_SUBSCRIPTION_ID")

        if os.environ.get("AZURE_CLIENT_SECRET"):
            self.client = ContainerInstanceManagementClient(
                ServicePrincipalCredentials(
                    client_id=os.environ.get("AZURE_CLIENT_ID"),
                    secret=os.environ.get("AZURE_CLIENT_SECRET"),
                    tenant=os.environ.get("AZURE_TENANT_ID"),
                ),
                self.subscription_id,
            )
            self.mode = "service_principal"
        elif self.cli_user:
            self.mode = "cli_profile"
            self.client = get_client_from_cli_profile(
                ContainerInstanceManagementClient, subscription_id=self.subscription_id
            )
        else:
            self.mode = "managed_identity"
            self.client = ContainerInstanceManagementClient(
                MSIAuthentication(), self.subscription_id
            )

        # Required parameters
        self.name = name
        self.resource_group_name = resource_group_name
        self.location = location
        self.image = image

        # default values
        self.cpus = 1
        self.mem = 1
        self.env_vars = []
        self.identity = None
        self.restart_policy = "Never"
        self.os_type = OperatingSystemTypes.linux
        self.command = None
        self.group = None
        self.instances = []

    def add_env_var(self, name, value):
        """
        add environement var
        
        Args:
            - name (str): env var name
            - value (str): env var value
        """
        self.env_vars.append(EnvironmentVariable(name=name, value=value))

    def set_cpus(self, cpus):
        """
        set cores number
        
        Args:
            - cpus (int): 1-4 (actual limit for westeurope)
        """
        self.cpus = cpus

    def set_mem(self, mem):
        """
        set amount of memory in GB
        
        Args:
            - mem (int): 1-14 (actual limit for westeurope)
        """
        self.mem = mem

    def set_identity(self, identity):
        """
        set user managed identity
        
        Args:
            - identity (taz.auth.UserAssignedIdentity): container group identity
        """
        self.identity = identity.get_container_group_identity()

    def set_command(self, command):
        """
        set command entry point of container
        
        Args:
            - command (str): entry point script of container
        """
        self.command = command

    def create(self):
        """
        Create the container group and instance
        """

        # Configure the container
        container_resource_requests = ResourceRequests(
            memory_in_gb=self.mem, cpu=self.cpus
        )
        container_resource_requirements = ResourceRequirements(
            requests=container_resource_requests
        )

        container = Container(
            name="container-001",
            image="{0}.azurecr.io/{1}:latest".format(
                self.image.container_registry.name, self.image.name
            ),
            resources=container_resource_requirements,
            environment_variables=self.env_vars,
            command=self.command,
        )

        group = ContainerGroup(
            location=self.location,
            containers=[container],
            os_type=self.os_type,
            restart_policy=self.restart_policy,
            image_registry_credentials=[
                self.image.container_registry.get_credentials()
            ],
            identity=self.identity,
        )

        self.client.container_groups.create_or_update(
            self.resource_group_name, self.name, group
        )

        self.group = self.client.container_groups.get(
            self.resource_group_name, self.name
        )

        for instance in self.group.containers:
            self.instances.append(instance)

    def get_group(self):
        """
        Return container group attribute
        
        Returns:
            - azure.mgmt.containerinstance.models.ContainerGroup: container 
                group object
        """
        return self.group

    def get_instances(self):
        """
        Summary
        
        Returns:
            - [ azure.mgmt.containerinstance.models.Container ]: List of
                container instances
        """
        return self.instances

    def delete(self):
        """
        delete container group and his containers
        """
        self.client.container_groups.delete(self.resource_group_name, self.name)

    def __str__(self):
        """
        prints container group as json string
        
        Returns:
            - str: json encoded as string
        """

        instances = []

        for instance in self.instances:
            try:
                state = instance.instance_view.current_state.state
            except:
                state = "unknown"
            instances.append(
                {"name": instance.name, "image": instance.image, "state": state,}
            )

        return json.dumps(
            {
                "name": self.group.name,
                "cpus": self.cpus,
                "mem": self.mem,
                "restart_policy": self.restart_policy,
                "command": self.command,
                "instances": instances,
            }
        )
